```
def RtoT(R_values, Chebyshev_fit):
    """use fit to calculate T from R for set of R_values
    by finding roots of Chebyshev series for modified coefficient
    root_fit.coef[0]= Chebyshev_fit.coef[0] - np.log(R_value) 
    then return as a set of T_values"""
    
    # fix if user inputs a scalar value instead of an array for R_values
    if np.isscalar(R_values): 
        values = np.array([R_values])
    else:
        values = R_values
    
    # prepare to find roots
    root_fit = Chebyshev_fit.copy()  #make a copy so as not to modify the original
    T_values = np.empty(values.size) #create an empty array to fill with T_values

    for index, value in enumerate(values): 
        root_fit.coef[0] = Chebyshev_fit.coef[0] - np.log(value) 
        roots = root_fit.roots()  # compute roots for R value
    
        #sort roots, find root that is real and within T domain
        T_solve = [np.real(np.exp(root)) for root in roots if ((root < Chebyshev_fit.domain.max() and root > Chebyshev_fit.domain.min()) and np.isreal(root))]

        #check that there is one and only one real root
        if len(T_solve) == 1: 
            T_value = T_solve[0] 
        elif len(T_solve) == 0:
            print('error! no real roots for R = ', value)
            T_value = np.nan
        else:
            print('warning! multiple real roots in domain for R =', value)
            print(T_solve)
            T_value = np.nan 
        # assign T_value to array
        T_values[index]   = T_value   # assign T value 
    return T_values
```